@@ -25,12 +25,12 @@ NULL
 #'
 #' Getters and setters to extract or replace parts of an object.
 #' @param x An object from which to get or set element(s).
-#' @param value A possible value for the element(s) of \code{x}.
-#' @param na.rm A \code{\link{logical}} scalar: should \code{\link{NA}} be
-#'  omitted?
+#' @param value A possible value for the element(s) of `x`.
+#' @param expected TODO.
+#' @param na.rm A [`logical`] scalar: should [`NA`] be omitted?
 #' @param ... Currently not used.
 #' @return
-#'  An object of the same sort as \code{x} with the new values assigned.
+#'  An object of the same sort as `x` with the new values assigned.
 #' @author N. Frerebeau
 #' @docType methods
 #' @family mutator
@@ -99,14 +99,14 @@ setGeneric(
 #' @aliases get_energy-method
 setGeneric(
   name = "get_energy",
-  def = function(x) standardGeneric("get_energy")
+  def = function(x, ...) standardGeneric("get_energy")
 )
 
 #' @rdname mutator
 #' @aliases set_energy-method
 setGeneric(
   name = "set_energy<-",
-  def = function(x, value) standardGeneric("set_energy<-")
+  def = function(x, ..., value) standardGeneric("set_energy<-")
 )
 
 #' @rdname mutator
@@ -151,15 +151,14 @@ setGeneric(
 #' @param x An object from which to extract element(s) or in which to
 #'  replace element(s).
 #' @param i,j Indices specifying elements to extract or replace. Indices are
-#'  \code{\link{numeric}}, \code{\link{integer}} or \code{\link{character}}
-#'  vectors or empty (missing) or \code{NULL}. Numeric values are coerced to
-#'  \code{\link{integer}} as by \code{\link{as.integer}} (and hence truncated
-#'  towards zero). Character vectors will be matched to the name of the
-#'  elements. An empty index (a comma separated blank) indicates that all
+#'  [`numeric`], [`integer`] or [`character`] vectors or empty (missing) or
+#'  `NULL`. Numeric values are coerced to [`integer`] as by [as.integer()] (and
+#'  hence truncated towards zero). Character vectors will be matched to the name
+#'  of the elements. An empty index (a comma separated blank) indicates that all
 #'  entries in that dimension are selected.
-# @param drop A \code{\link{logical}} scalar: should the result be coerced to
-#  the lowest possible dimension? This only works for extracting elements,
-#  not for the replacement.
+# @param drop A [`logical`] scalar: should the result be coerced to the lowest
+#  possible dimension? This only works for extracting elements, not for the
+#  replacement.
 #' @return
 #'  A subsetted object.
 #' @author N. Frerebeau
@@ -172,35 +171,30 @@ NULL
 # Operators ====================================================================
 #' Common Operations on GammaSpectrum Objects
 #'
-#' Performs common operations on \code{GammaSpectrum} objects.
-#' @param x,e1,e2 An object (typically a \linkS4class{GammaSpectrum} object).
-#' @param digits A length-one \code{\link{numeric}} vector giving the
-#'  number of digits to be used in \code{\link{round}} or \code{\link{signif}}.
-#' @param na.rm A \code{\link{logical}} scalar: should missing values
-#'  (including \code{NaN}) be omitted from the calculations?
+#' Performs common operations on `GammaSpectrum` objects.
+#' @param x,e1,e2 An object (typically a [GammaSpectrum-class] object).
+#' @param digits A length-one [`numeric`] vector giving the number of digits to
+#'  be used in [round()] or [signif()].
+#' @param na.rm A [`logical`] scalar: should missing values (including `NaN`) be
+#'  omitted from the calculations?
 #' @param ... Further arguments passed to or from methods.
 #' @section Group Generics:
-#'  \linkS4class{GammaSpectrum} objects have support for S4 group generic
+#'  [GammaSpectrum-class] objects have support for S4 group generic
 #'  functionality to operate within elements across objects:
 #'  \describe{
-#'   \item{\code{Arith}}{"\code{+}", "\code{-}", "\code{*}", "\code{^}",
-#'   "\code{\%\%}", "\code{\%/\%}", "\code{/}"}
-#'   \item{\code{Compare}}{"\code{==}", "\code{>}", "\code{<}", "\code{!=}",
-#'   "\code{<=}", "\code{>=}"}
-#'   \item{\code{Logic}}{"\code{&}", "\code{|}"}
-#'   \item{\code{Math}}{"\code{abs}", "\code{sign}", "\code{sqrt}",
-#'   "\code{ceiling}", "\code{floor}", "\code{trunc}", "\code{cummax}",
-#'   "\code{cummin}", "\code{cumprod}", "\code{cumsum}", "\code{log}",
-#'   "\code{log10}", "\code{log2}", "\code{log1p}", "\code{acos}",
-#'   "\code{acosh}", "\code{asin}", "\code{asinh}", "\code{atan}",
-#'   "\code{atanh}", "\code{exp}", "\code{expm1}", "\code{cos}",
-#'   "\code{cosh}", "\code{cospi}", "\code{sin}", "\code{sinh}",
-#'   "\code{sinpi}", "\code{tan}", "\code{tanh}", "\code{tanpi}",
-#'   "\code{gamma}", "\code{lgamma}", "\code{digamma}", "\code{trigamma}"}
-#'   \item{\code{Math2}}{"\code{round}", "\code{signif}"}
-#'   \item{\code{Ops}}{"\code{Arith}", "\code{Compare}", "\code{Logic}"}
-#'   \item{\code{Summary}}{"\code{min}", "\code{max}", "\code{range}",
-#'   "\code{prod}", "\code{sum}", "\code{any}", "\code{all}"}
+#'   \item{`Arith`}{"`+`", "`-`", "`*`", "`^`", "`\%\%`", "`\%/\%`", "`/`"}
+#'   \item{`Compare`}{"`==`", "`>`", "`<`", "`!=`", "`<=`", "`>=`"}
+#'   \item{`Logic`}{"`&`", "`|`"}
+#'   \item{`Math`}{"`abs`", "`sign`", "`sqrt`", "`ceiling`", "`floor`",
+#'   "`trunc`", "`cummax`", "`cummin`", "`cumprod`", "`cumsum`", "`log`",
+#'   "`log10`", "`log2`", "`log1p`", "`acos`", "`acosh`", "`asin`", "`asinh`",
+#'   "`atan`", "`atanh`", "`exp`", "`expm1`", "`cos`", "`cosh`", "`cospi`",
+#'   "`sin`", "`sinh`", "`sinpi`", "`tan`", "`tanh`", "`tanpi`", "`gamma`",
+#'   "`lgamma`", "`digamma`", "`trigamma`"}
+#'   \item{`Math2`}{"`round`", "`signif`"}
+#'   \item{`Ops`}{"`Arith`", "`Compare`", "`Logic`"}
+#'   \item{`Summary`}{"`min`", "`max`", "`range`", "`prod`", "`sum`", "`any`",
+#'   "`all`"}
 #'  }
 #' @example inst/examples/ex-operators.R
 #' @author N. Frerebeau
@@ -214,18 +208,17 @@ NULL
 #' Energy Scale Calibration
 #'
 #' Calibrates the energy scale of a gamma spectrum.
-#' @param object A \linkS4class{GammaSpectrum} or
-#'  \linkS4class{GammaSpectra} object.
-#' @param lines A \linkS4class{PeakPosition} object or a \code{\link{list}} of
-#'  length two. If a \code{list} is provided, each element must be a named
-#'  numeric vector giving the observed peak position ("\code{channel}") and the
-#'  corresponding expected "\code{energy}" value (in keV).
+#' @param object A [GammaSpectrum-class] or [GammaSpectra-class] object.
+#' @param lines A [PeakPosition-class] object or a [`list`] of length two. If a
+#'  `list` is provided, each element must be a named numeric vector giving the
+#'  observed peak position ("`channel`") and the corresponding expected
+#'  "`energy`" value (in keV).
 #' @param ... Currently not used.
 #' @details
 #'  The energy calibration of a spectrum is the most tricky part. To do this,
 #'  the user must specify the position of at least three observed peaks and the
 #'  corresponding energy value (in keV). A second order polynomial model is
-#'  fitted on these energy \emph{vs} channel values, then used to predict the
+#'  fitted on these energy *vs* channel values, then used to predict the
 #'  new energy scale of the spectrum.
 #'
 #'  The package allows to provide the channel-energy pairs to be use. However,
@@ -239,9 +232,8 @@ NULL
 #'  Regardless of the approach you choose, it is strongly recommended to check
 #'  the result before proceeding.
 #' @return
-#'  \code{energy_calibrate} returns a \linkS4class{GammaSpectrum} object.
-#'
-#'  \code{has_energy} returns a \code{\link{logical}} vector.
+#'  * `energy_calibrate()` returns a [GammaSpectrum-class] object.
+#'  * `has_energy()` returns a [`logical`] vector.
 #' @example inst/examples/ex-energy.R
 #' @author N. Frerebeau
 #' @docType methods
@@ -266,62 +258,64 @@ setGeneric(
 # Baseline =====================================================================
 #' Baseline Estimation and Removal
 #'
-#' @param object A \linkS4class{GammaSpectrum} or \linkS4class{GammaSpectra}
+#' @param object A [GammaSpectrum-class] or [GammaSpectra-class]
 #'  object.
-#' @param method A \code{\link{character}} string specifying the method to be
-#'  used for baseline estimation (see details). Any unambiguous substring
-#'  can be given.
-#' @param LLS A \code{\link{logical}} scalar: should the LLS operator be applied
-#'  on \code{x} before employing SNIP algorithm? Only used if
-#'  \code{method} is "\code{SNIP}".
-#' @param decreasing A \code{\link{logical}} scalar: should a decreasing
-#'  clipping window be used? Only used if \code{method} is "\code{SNIP}".
-#' @param n An \code{\link{integer}} value giving the number of iterations.
-#'  Only used if \code{method} is "\code{SNIP}".
-#' @param noise A length-one \code{\link{numeric}} vector giving the noise
-#' level. Only used if \code{method} is "\code{rubberband}".
-#' @param spline A \code{\link{logical}} scalar: should spline interpolation
-#' through the support points be used instead of linear interpolation?
-#' Only used if \code{method} is "\code{rubberband}".
+#' @param method A [`character`] string specifying the method to be used for
+#'  baseline estimation (see details). Any unambiguous substring can be given.
+#' @param LLS A [`logical`] scalar: should the LLS operator be applied on `x`
+#'  before employing SNIP algorithm? Only used if `method` is "`SNIP`".
+#' @param decreasing A [`logical`] scalar: should a decreasing clipping window
+#'  be used? Only used if `method` is "`SNIP`".
+#' @param n An [`integer`] value giving the number of iterations.
+#'  Only used if `method` is "`SNIP`".
+#' @param noise A length-one [`numeric`] vector giving the noise level.
+#'  Only used if `method` is "`rubberband`".
+#' @param spline A [`logical`] scalar: should spline interpolation through the
+#'  support points be used instead of linear interpolation?
+#'  Only used if `method` is "`rubberband`".
+#' @param from An [`integer`] giving the first channel to be used for linear
+#'  interpolation. If `NULL` (the default), channel \eqn{1} is used.
+#'  Only used if `method` is "`linear`".
+#' @param to An [`integer`] giving the last channel to be used for linear
+#'  interpolation. If `NULL` (the default), channel \eqn{max} is used.
+#'  Only used if `method` is "`linear`".
 #' @param ... Extra parameters to be passed to further methods.
 #' @details
 #'  The following methods are available for baseline estimation:
 #'  \describe{
-#'   \item{SNIP}{Sensitive Nonlinear Iterative Peak clipping algorithm.}
-#'   \item{rubberband}{A convex envelope of the spectrum is determined and the
+#'   \item{`SNIP`}{Sensitive Nonlinear Iterative Peak clipping algorithm.}
+#'   \item{`rubberband`}{A convex envelope of the spectrum is determined and the
 #'   baseline is estimated as the part of the convex envelope lying below the
 #'   spectrum. Note that the rubber band does not enter the concave regions
 #'   (if any) of the spectrum.}
+#'   \item{`linear`}{Linear baseline estimation.}
 #'  }
 #' @note
-#'  \code{baseline_rubberband} is slightly modified from C. Beleites'
-#'  \code{\link[hyperSpec]{spc.rubberband}}.
+#'  `baseline_rubberband()` is slightly modified from C. Beleites'
+#'  [hyperSpec::spc.rubberband()].
 #' @return
-#'  \code{baseline_*} returns a \linkS4class{BaseLine} object.
-#'
-#'  \code{signal_correct} returns a corrected \linkS4class{GammaSpectrum} or
-#'  \linkS4class{GammaSpectra} object (same as \code{object}).
+#'  * `baseline_*()` returns a [BaseLine-class] object.
+#'  * `signal_correct()` returns a corrected [GammaSpectrum-class] or
+#'    [GammaSpectra-class] object (same as `object`).
 #' @references
 #'  Liland, K. H. (2015). 4S Peak Filling - baseline estimation by iterative
-#'  mean suppression. \emph{MethodsX}, 2, 135-140.
-#'  \doi{10.1016/j.mex.2015.02.009}.
+#'  mean suppression. *MethodsX*, 2, 135-140. \doi{10.1016/j.mex.2015.02.009}.
 #'
 #'  Morháč, M., Kliman, J., Matoušek, V., Veselský, M. & Turzo, I. (1997).
 #'  Background elimination methods for multidimensional gamma-ray spectra.
-#'  \emph{Nuclear Instruments and Methods in Physics Research Section A:
-#'  Accelerators, Spectrometers, Detectors and Associated Equipment}, 401(1),
-#'  p. 113-132.
-#'  \doi{10.1016/S0168-9002(97)01023-1}
+#'  *Nuclear Instruments and Methods in Physics Research Section A:
+#'  Accelerators, Spectrometers, Detectors and Associated Equipment*, 401(1),
+#'  p. 113-132. \doi{10.1016/S0168-9002(97)01023-1}
 #'
 #'  Morháč, M. & Matoušek, V. (2008). Peak Clipping Algorithms for Background
-#'  Estimation in Spectroscopic Data. \emph{Applied Spectroscopy}, 62(1), p. 91-106.
+#'  Estimation in Spectroscopic Data. *Applied Spectroscopy*, 62(1), p. 91-106.
 #'  \doi{10.1366/000370208783412762}
 #'
 #'  Ryan, C. G., Clayton, E., Griffin, W. L., Sie, S. H. & Cousens, D. R.
 #'  (1988). SNIP, a statistics-sensitive background treatment for the
 #'  quantitative analysis of PIXE spectra in geoscience applications.
-#'  \emph{Nuclear Instruments and Methods in Physics Research Section B:
-#'  Beam Interactions with Materials and Atoms}, 34(3), p. 396-402.
+#'  *Nuclear Instruments and Methods in Physics Research Section B:
+#'  Beam Interactions with Materials and Atoms*, 34(3), p. 396-402.
 #'  \doi{10.1016/0168-583X(88)90063-8}
 #' @example inst/examples/ex-baseline.R
 #' @author N. Frerebeau
@@ -359,6 +353,13 @@ setGeneric(
   def = function(object, ...) standardGeneric("baseline_rubberband")
 )
 
+#' @rdname baseline
+#' @aliases baseline_linear-method
+setGeneric(
+  name = "baseline_linear",
+  def = function(object, ...) standardGeneric("baseline_linear")
+)
+
 # @rdname baseline
 # @aliases baseline_rollingball-method
 # setGeneric(
@@ -379,31 +380,30 @@ setGeneric(
 #' \code{dose_fit} builds a calibration curve for gamma dose rate estimation.
 #'
 #' \code{dose_predict} predicts in situ gamma dose rate.
-#' @param object A \linkS4class{GammaSpectra} or \linkS4class{CalibrationCurve}
-#'  object.
-#' @param background A \linkS4class{GammaSpectrum} object of a length-two
-#'  \code{\link{numeric}} vector giving the background noise integration value
-#'  and error, respectively.
-#' @param doses A \code{\link{matrix}} or \code{\link{data.frame}} TODO.
-#' @param range_Ni,range_NiEi A length-two \code{\link{numeric}} vector giving
-#'  the energy range to integrate within (in keV).
-#' @param alpha A \code{\link{numeric}} value giving the cutoff value for
-#'  confidence intervals (see \code{\link[IsoplotR]{york}}).
-#' @param details A \code{\link{list}} of length-one vector specifying
-#'  additional informations about the instrument for which the curve is built.
-#' @param spectrum An optional \linkS4class{GammaSpectrum} or
-#'  \linkS4class{GammaSpectra} object in which to look for variables with which
-#'  to predict. If omitted, the fitted values are used.
-#' @param sigma A \code{\link{numeric}} value giving TODO.
-#' @param epsilon A \code{\link{numeric}} value giving an extra error term
+#' @param object A [GammaSpectra-class] or [CalibrationCurve-class] object.
+#' @param background A [GammaSpectrum-class] object of a length-two [`numeric`]
+#'  vector giving the background noise integration value and error,
+#'  respectively.
+#' @param doses A [`matrix`] or [`data.frame`] TODO.
+#' @param range_Ni,range_NiEi A length-two [`numeric`] vector giving the energy
+#'  range to integrate within (in keV).
+#' @param alpha A [`numeric`] value giving the cutoff value for confidence
+#'  intervals (see [IsoplotR::york()]).
+#' @param details A [`list`] of length-one vector specifying additional
+#'  informations about the instrument for which the curve is built.
+#' @param spectrum An optional [GammaSpectrum-class] or [GammaSpectra-class]
+#'  object in which to look for variables with which to predict. If omitted,
+#'  the fitted values are used.
+#' @param sigma A [`numeric`] value giving TODO.
+#' @param epsilon A [`numeric`] value giving an extra error term
 #'  introduced by the calibration of the energy scale of the spectrum.
 #' @param ... Currently not used.
 #' @details
 #'  To estimate the gamma dose rate, one of the calibration curves distributed
-#'  with this package can be used (fig. \@ref(fig:curve)). These built-in curves
-#'  are in use in several luminescence dating laboratories and can be used to
-#'  replicate published results. As these curves are instrument specific, the
-#'  user may have to build its own curve.
+#'  with this package can be used. These built-in curves are in use in several
+#'  luminescence dating laboratories and can be used to replicate published
+#'  results. As these curves are instrument specific, the user may have to build
+#'  its own curve.
 #'
 #'  The construction of a calibration curve requires a set of reference spectra
 #'  for which the gamma dose rate is known and a background noise measurement.
@@ -412,33 +412,28 @@ setGeneric(
 #'  is finally modelled by the integrated signal value used as a linear
 #'  predictor (York *et al.*, 2004).
 #'
-#'  See \code{vignette(doserate)} for a reproducible example.
+#'  See `vignette(doserate)` for a reproducible example.
 #' @return
-#'  \code{dose_fit} returns a \linkS4class{CalibrationCurve} object.
-#'
-#'  \code{dose_predict} returns a \code{\link{data.frame}} with the following
-#'  columns:
+#'  * `dose_fit()` returns a [CalibrationCurve-class] object.
+#'  * `dose_predict()` returns a [`data.frame`] with the following columns:
 #'  \describe{
-#'   \item{name}{(\code{\link{character}}) the name of the spectra.}
-#'   \item{*_signal}{(\code{\link{numeric}}) the integrated signal value
-#'   (according to the value of \code{threshold}; see
-#'   \code{\link{signal_integrate}}).}
-#'   \item{*_error}{(\code{\link{numeric}}) the integrated signal error value
-#'   (according to the value of \code{threshold}; see
-#'   \code{\link{signal_integrate}}).}
-#'   \item{gamma_signal}{(\code{\link{numeric}}) the predicted gamma dose rate.}
-#'   \item{gamma_error}{(\code{\link{numeric}}) the predicted gamma dose rate
-#'   error.}
+#'   \item{`name`}{([`character`]) the name of the spectra.}
+#'   \item{`*_signal`}{([`numeric`]) the integrated signal value (according to
+#'   the value of `threshold`; see [signal_integrate()]).}
+#'   \item{`*_error`}{([`numeric`]) the integrated signal error value
+#'   (according to the value of `threshold`; see [signal_integrate()]).}
+#'   \item{`gamma_signal`}{([`numeric`]) the predicted gamma dose rate.}
+#'   \item{`gamma_error`}{([`numeric`]) the predicted gamma dose rate error.}
 #'  }
-#' @seealso \link{signal_integrate}
+#' @seealso [signal_integrate()]
 #' @references
 #'  Mercier, N. & Falguères, C. (2007). Field Gamma Dose-Rate Measurement with
 #'  a NaI(Tl) Detector: Re-Evaluation of the "Threshold" Technique.
-#'  \emph{Ancient TL}, 25(1), p. 1-4.
+#'  *Ancient TL*, 25(1), p. 1-4.
 #'
 #'  York, D., Evensen, N. M., Martínez, M. L. & De Basabe Delgado, J. (2004).
 #'  Unified Equations for the Slope, Intercept, and Standard Errors of the Best
-#'  Straight Line. \emph{American Journal of Physics}, 72(3), p. 367-75.
+#'  Straight Line. *American Journal of Physics*, 72(3), p. 367-75.
 #'  \doi{10.1119/1.1632486}.
 #' @example inst/examples/ex-doserate.R
 #' @author N. Frerebeau
@@ -465,30 +460,28 @@ setGeneric(
 # Integrate ====================================================================
 #' Signal Integration
 #'
-#' @param object A \linkS4class{GammaSpectrum} or \linkS4class{GammaSpectra}
-#'  object.
-#' @param background A \linkS4class{GammaSpectrum} object.
-#' @param range A length-two \code{\link{numeric}} vector giving the energy
-#'  range to integrate within (in keV).
-#' @param energy A \code{\link{logical}} scalar: TODO?
-#' @param simplify A \code{\link{logical}} scalar: should the result be
-#'  simplified to a matrix? The default value, \code{FALSE}, returns a list.
+#' @param object A [GammaSpectrum-class] or [GammaSpectra-class] object.
+#' @param background A [GammaSpectrum-class] object.
+#' @param range A length-two [`numeric`] vector giving the energy range to
+#'  integrate within (in keV).
+#' @param energy A [`logical`] scalar: TODO?
+#' @param simplify A [`logical`] scalar: should the result be simplified to a
+#'  [`matrix`]? The default value, `FALSE`, returns a [`list`].
 #' @param ... Currently not used.
 #' @details
 #'  It assumes that each spectrum has an energy scale.
 #' @return
-#'  If \code{simplify} is \code{FALSE} (the default) returns a
-#'  \code{\link{list}} of numeric vectors (the signal value and its error),
-#'  else returns a \code{\link{matrix}}.
+#'  If `simplify` is `FALSE` (the default) returns a [`list`] of numeric vectors
+#'  (the signal value and its error), else returns a [`matrix`].
 #' @references
 #'  Guérin, G. & Mercier, M. (2011). Determining Gamma Dose Rates by Field Gamma
 #'  Spectroscopy in Sedimentary Media: Results of Monte Carlo Simulations.
-#'  \emph{Radiation Measurements}, 46(2), p. 190-195.
+#'  *Radiation Measurements*, 46(2), p. 190-195.
 #'  \doi{10.1016/j.radmeas.2010.10.003}.
 #'
 #'  Mercier, N. & Falguères, C. (2007). Field Gamma Dose-Rate Measurement with
 #'  a NaI(Tl) Detector: Re-Evaluation of the "Threshold" Technique.
-#'  \emph{Ancient TL}, 25(1), p. 1-4.
+#'  *Ancient TL*, 25(1), p. 1-4.
 #' @author N. Frerebeau
 #' @docType methods
 #' @family signal processing
@@ -500,18 +493,17 @@ setGeneric(
 )
 
 # Peaks ========================================================================
-#' Peaks
+#' Find Peaks
 #'
 #' Finds local maxima in sequential data.
-#' @param object A \linkS4class{GammaSpectrum} or \linkS4class{PeakPosition}
-#'  object.
-#' @param method A \code{\link{character}} string specifying the method to be
-#'  used for background noise estimation (see below).
-#' @param SNR An \code{\link{integer}} giving the signal-to-noise-ratio for
-#'  peak detection (see below).
-#' @param span An \code{\link{integer}} giving the half window size (in number
-#'  of channels). If \code{NULL}, 5\% of the number of channels is used as the
-#'  half window size.
+#' @param object A [GammaSpectrum-class] object.
+#' @param method A [`character`] string specifying the method to be used for
+#'  background noise estimation (see below).
+#' @param SNR An [`integer`] giving the signal-to-noise-ratio for peak detection
+#'  (see below).
+#' @param span An [`integer`] giving the half window size (in number of
+#'  channels). If `NULL`, 5\% of the number of channels is used as the half
+#'  window size.
 #' @param ... Extra parameters to be passed to internal methods.
 #' @details
 #'  A local maximum has to be the highest one in the given window and has to be
@@ -519,45 +511,74 @@ setGeneric(
 #'
 #'  The following methods are available for noise estimation:
 #'  \describe{
-#'   \item{MAD}{Median Absolute Deviation.}
+#'   \item{`MAD`}{Median Absolute Deviation.}
 #'  }
-#' @return An object of class \linkS4class{PeakPosition}.
+#' @return A [PeakPosition-class] object.
 #' @example inst/examples/ex-peaks.R
 #' @author N. Frerebeau
 #' @docType methods
 #' @family signal processing
-#' @rdname peaks
+#' @rdname peaks_find
 #' @aliases peaks_find-method
 setGeneric(
   name = "peaks_find",
   def = function(object, ...) standardGeneric("peaks_find")
 )
 
+#' Search Peaks
+#'
+#' Search the maxima in sequential data around a given value.
+#' @param object A [GammaSpectrum-class] object.
+#' @param index A vector giving the expected peak position.
+#'  If `index` is a [`numeric`] vector, peaks are searched by energy (`index` is
+#'  assumed to be expressed in keV). If `index` is an [`integer`] vector, peaks
+#'  are searched by channel.
+#' @param span A [`numeric`] value giving the half window size for searching.
+#'  If `index` is a [`numeric`] vector, `span` is expressed in keV.
+#'  If `index` is an [`integer`] vector, `span` is expressed in channel.
+#' @param tolerance A [`numeric`] value giving the threshold above which a
+#'  warning/error is raised.
+#' @param ... Currently not used.
+#' @return A [PeakPosition-class] object.
+#' @example inst/examples/ex-peaks.R
+#' @author N. Frerebeau
+#' @docType methods
+#' @family signal processing
+#' @rdname peaks_search
+#' @aliases peaks_search-method
+setGeneric(
+  name = "peaks_search",
+  def = function(object, index, ...) standardGeneric("peaks_search")
+)
+
 # Plot =========================================================================
 #' Plot
 #'
 #' @param x,y Objects to be plotted.
-#' @param xaxis,yaxis A \code{\link{character}} string specifying the data to
-#'  be plotted along each axis. It must be one of "\code{energy}" or
-#'  "\code{channel}" (\code{x} axis) and "\code{counts}" or "\code{rate}"
-#'  (\code{y} axis). Any unambiguous substring can be given.
-#' @param select A \code{\link{numeric}} or \code{\link{character}} vector
-#'  giving the selection of the spectrum that are drawn.
-#' @param facet A \code{\link{logical}} scalar: should a matrix of panels
-#'  defined by spectrum be drawn?
-#' @param error_ellipse A \code{\link{logical}} scalar: should error ellipses
-#'  be plotted?
-#' @param error_bar A \code{\link{logical}} scalar: should error bars
-#'  be plotted?
-#' @param level length-one \code{\link{numeric}} vector giving the the
-#'  probability cutoff for the error ellipses.
-#' @param n A length-one \code{\link{numeric}} vector giving the resolution of
-#'  the error ellipses.
-#' @param energy A \code{\link{logical}} scalar: TODO.
+#' @param xaxis,yaxis A [`character`] string specifying the data to be plotted
+#'  along each axis. It must be one of "`energy`" or "`channel`" (`x` axis) and
+#'  "`counts`" or "`rate`" (`y` axis). Any unambiguous substring can be given.
+#' @param select A [`numeric`] or [`character`] vector giving the selection of
+#'  the spectrum that are drawn.
+#' @param facet A [`logical`] scalar: should a matrix of panels defined by
+#'  spectrum be drawn?
+#' @param nrow A [`character`] string specifying the number of rows.
+#'  It must be one of "`fixed`" or "`auto`". Any unambiguous substring can be
+#'  given. Only used if `facet` is `TRUE`.
+#' @param split A [`logical`] scalar: should.
+#' @param span An [`integer`] giving the half window size (in number of
+#'  channels). Only used if `split` is `TRUE`.
+#' @param error_ellipse A [`logical`] scalar: should error ellipses be plotted?
+#' @param error_bar A [`logical`] scalar: should error bars be plotted?
+#' @param level length-one [`numeric`] vector giving the the probability cutoff
+#'  for the error ellipses.
+#' @param n A length-one [`numeric`] vector giving the resolution of the error
+#'  ellipses.
+#' @param energy A [`logical`] scalar: TODO.
 #' @param ... Currently not used.
 #' @return
-#'  A \code{\link[ggplot2]{ggplot}} object.
-#' @seealso \link[IsoplotR]{ellipse}, \link[IsoplotR]{isochron}
+#'  A [ggplot2::ggplot] object.
+#' @seealso [IsoplotR::ellipse()], [IsoplotR::isochron()]
 #' @example inst/examples/ex-plot.R
 #' @author N. Frerebeau
 #' @docType methods
@@ -576,18 +597,16 @@ if (!isGeneric("plot")) {
 #' Data Input
 #'
 #' Reads a gamma ray spectrum file.
-#' @param file A \code{\link{character}} string giving the path of files to be
-#'  imported.
-#' @param extensions A \code{\link{character}} vector specifying the possible
-#'  file extensions. It must be one or more of "\code{cnf}", "\code{tka}".
-#' @param ... Extra parameters to be passed to
-#'  \code{\link[rxylib]{read_xyData}}.
+#' @param file A [`character`] string giving the path of files to be imported.
+#' @param extensions A [`character`] vector specifying the possible
+#'  file extensions. It must be one or more of "`cnf`", "`tka`".
+#' @param ... Extra parameters to be passed to [rxylib::read_xyData()].
 #' @note
-#'  \emph{Only supports Canberra CNF and TKA files.}
+#'  Only supports Canberra CNF and TKA files.
 #' @return
-#'  A \linkS4class{GammaSpectra} object if more than one spectrum are imported
-#'  at once, else a \linkS4class{GammaSpectrum} object.
-#' @seealso \link[rxylib]{read_xyData}
+#'  A [GammaSpectra-class] object if more than one spectrum are imported
+#'  at once, else a [GammaSpectrum-class] object.
+#' @seealso [rxylib::read_xyData()]
 #' @example inst/examples/ex-read.R
 #' @author N. Frerebeau
 #' @docType methods
@@ -599,15 +618,16 @@ setGeneric(
   def = function(file, ...) standardGeneric("read")
 )
 
-# Slice ========================================================================
+# Signal processing ============================================================
+## Slice -----------------------------------------------------------------------
 #' Choose channels by Position
 #'
 #' Choose channels by position.
-#' @param object A \linkS4class{GammaSpectrum} or \linkS4class{GammaSpectra}
+#' @param object A [GammaSpectrum-class] or [GammaSpectra-class]
 #'  object.
-#' @param ... \code{\link{integer}} values giving the channels of the
-#'  spectrum to be kept/dropped (see below). Numeric values are coerced to
-#'  integer as by \code{\link{as.integer}} (and hence truncated towards zero).
+#' @param ... [`integer`] values giving the channels of the spectrum to be
+#'  kept/dropped (see below). Numeric values are coerced to integer as by
+#'  [as.integer()] (and hence truncated towards zero).
 #' @details
 #'  Either positive values to keep, or negative values to drop, should be
 #'  provided. The values provided must be either all positive or all negative.
@@ -618,61 +638,79 @@ setGeneric(
 #'  artefact produced by the rapid growth of random background noise towards low
 #'  energies.
 #' @return
-#'  A \linkS4class{GammaSpectrum} or \linkS4class{GammaSpectra} object.
+#'  A [GammaSpectrum-class] or [GammaSpectra-class] object.
 #' @author N. Frerebeau
 #' @example inst/examples/ex-slice.R
 #' @docType methods
 #' @family signal processing
-#' @rdname slice
+#' @rdname signal_slice
 #' @aliases signal_slice-method
 setGeneric(
   name = "signal_slice",
   def = function(object, ...) standardGeneric("signal_slice")
 )
 
-# Smooth =======================================================================
+## Split -----------------------------------------------------------------------
+#' Split
+#'
+#' @param object A [GammaSpectrum-class] object.
+#' @param groups A a [`factor`] in the sense that `as.factor(groups)` defines
+#'  the grouping (see [`split`]).
+#' @param ... Currently not used.
+#' @return
+#'  A [GammaSpectra-class] object.
+#' @author N. Frerebeau
+#' @example inst/examples/ex-slice.R
+#' @docType methods
+#' @family signal processing
+#' @rdname signal_split
+#' @aliases signal_split-method
+setGeneric(
+  name = "signal_split",
+  def = function(object, ...) standardGeneric("signal_split")
+)
+
+## Smooth ----------------------------------------------------------------------
 #' Smooth
 #'
 #' Smoothes intensities.
-#' @param object A \linkS4class{GammaSpectrum} or \linkS4class{GammaSpectra}
+#' @param object A [GammaSpectrum-class] or [GammaSpectra-class]
 #'  object.
-#' @param method A \code{\link{character}} string specifying the smoothing
-#'  method to be used. It must be one of "\code{unweighted}" (default),
-#'  "\code{weighted}" or "\code{savitzky}" (see details).
-#'  Any unambiguous substring can be given.
-#' @param m An odd \code{\link{integer}} giving the number of adjacent
-#'  points to be used.
-#' @param p An \code{\link{integer}} giving the polynomial degree.
-#'  Only used if \code{method} is "\code{savitzky}".
+#' @param method A [`character`] string specifying the smoothing method to be
+#'  used. It must be one of "`unweighted`" (default), "`weighted`" or
+#'  "`savitzky`" (see details). Any unambiguous substring can be given.
+#' @param m An odd [`integer`] giving the number of adjacent points to be used.
+#' @param p An [`integer`] giving the polynomial degree. Only used if `method`
+#'  is "`savitzky`".
 #' @param ... Extra parameters to be passed to further methods.
 #' @details
 #'  The following smoothing methods are available:
 #'  \describe{
-#'   \item{rectangular}{Unweighted sliding-average or rectangular smooth.
+#'   \item{`rectangular`}{Unweighted sliding-average or rectangular smooth.
 #'   It replaces each point in the signal with the average of \eqn{m} adjacent
 #'   points.}
-#'   \item{triangular}{Weighted sliding-average or triangular smooth.
+#'   \item{`triangular`}{Weighted sliding-average or triangular smooth.
 #'   It replaces each point in the signal with the weighted mean of \eqn{m}
 #'   adjacent points.}
-#'   \item{savitzky}{Savitzky-Golay filter. This method is based on the
+#'   \item{`savitzky`}{Savitzky-Golay filter. This method is based on the
 #'   least-squares fitting of polynomials to segments of \eqn{m} adjacent
 #'   points.}
 #'  }
 #'  There will be \eqn{(m - 1) / 2} points both at the beginning and at the end
 #'  of the spectrum for which a complete \eqn{m}-width smooth cannot be
 #'  calculated. To prevent data loss, progressively smaller smooths are used at
-#'  the ends of the spectrum if \code{method} is \code{unweighted} or
-#'  \code{weighted}. If the Savitzky-Golay filter is used, the original
-#'  \eqn{(m - 1) / 2} points at the ends of the spectrum are preserved.
+#'  the ends of the spectrum if `method` is `unweighted` or `weighted`. If the
+#'  Savitzky-Golay filter is used, the original \eqn{(m - 1) / 2} points at the
+#'  ends of the spectrum are preserved.
 #' @return
-#'  A \linkS4class{GammaSpectrum} or \linkS4class{GammaSpectra} object.
+#'  A [GammaSpectrum-class] or [GammaSpectra-class] object.
 #' @references
 #'  Gorry, P. A. (1990). General Least-Squares Smoothing and Differentiation by
-#'  the Convolution (Savitzky-Golay) Method. \emph{Analytical Chemistry}, 62(6),
+#'  the Convolution (Savitzky-Golay) Method. *Analytical Chemistry*, 62(6),
 #'  p. 570-573. \doi{10.1021/ac00205a007}.
 #'
 #'  Savitzky, A. & Golay, M. J. E. (1964). Smoothing and Differentiation of
-#'  Data by Simplified Least Squares Procedures. \emph{Analytical Chemistry},
+#'  Data by Simplified Least Squares Procedures. *Analytical Chemistry*,
 #'  36(8), p. 1627-1639. \doi{10.1021/ac60214a047}.
 #' @author N. Frerebeau
 #' @example inst/examples/ex-smooth.R
@@ -710,18 +748,18 @@ setGeneric(
   def = function(object, ...) standardGeneric("smooth_savitzky")
 )
 
-# Stabilize ====================================================================
+## Stabilize -------------------------------------------------------------------
 #' Transform Intensities
 #'
-#' @param object A \linkS4class{GammaSpectrum} object.
-#' @param f A \code{\link{function}} that takes a numeric vector as
+#' @param object A [GammaSpectrum-class] object.
+#' @param f A [`function`] that takes a numeric vector as
 #'  argument and returns a numeric vector.
-#' @param ... Extra arguments to be passed to \code{transformation}.
+#' @param ... Extra arguments to be passed to `f`.
 #' @details
 #'  The stabilization step aims at improving the identification of peaks with a
 #'  low signal-to-noise ratio. This particularly targets higher energy peaks.
-#' @return A new \linkS4class{GammaSpectrum} or \linkS4class{GammaSpectra}
-#'  object with transformed intensities.
+#' @return A [GammaSpectrum-class] or [GammaSpectra-class] object with
+#'  transformed intensities.
 #' @author N. Frerebeau
 #' @docType methods
 #' @family signal processing
@@ -735,10 +773,9 @@ setGeneric(
 # Summarize ====================================================================
 #' Summarize
 #'
-#' @param object A \linkS4class{GammaSpectrum} or \linkS4class{GammaSpectra}
-#' object.
+#' @param object A [GammaSpectrum-class] or [GammaSpectra-class] object.
 #' @param ... Currently not used.
-#' @return A \code{\link{data.frame}}.
+#' @return A [`data.frame`].
 #' @author N. Frerebeau
 #' @example inst/examples/ex-summarise.R
 #' @docType methods
